@@ -1,7 +1,7 @@
 /* magconf.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -117,7 +117,7 @@ magconf_setting_clone (Magnifier *magnifier)
     value->cursor_state	= magnifier->cursor_state;
     value->cursor_name	= g_strdup (magnifier->cursor_name);
     value->cursor_size	= magnifier->cursor_size;
-    value->cursor_mag   = magnifier->cursor_mag;
+    value->cursor_scale = magnifier->cursor_scale;
     value->cursor_color = magnifier->cursor_color;
     
     value->crosswire 	= magnifier->crosswire;
@@ -138,6 +138,8 @@ magconf_setting_init (const gchar *id,
 		      gboolean set_struct)
 {
     Magnifier *value = NULL;
+    gint size_x, size_y;
+    
     value = magconf_setting_new ();
     
     sru_assert (value);
@@ -146,6 +148,8 @@ magconf_setting_init (const gchar *id,
     else	
 	value->id	= g_strdup (DEFAULT_MAGNIFIER_ID);
 	
+    magconf_get_display_size (&size_x, &size_y);
+	
 	
     value->source 	= g_strdup (DEFAULT_MAGNIFIER_SOURCE);
     value->target 	= g_strdup (DEFAULT_MAGNIFIER_TARGET);
@@ -153,7 +157,6 @@ magconf_setting_init (const gchar *id,
     (value->zp).top	= DEFAULT_MAGNIFIER_ZP_TOP;
     (value->zp).height	= DEFAULT_MAGNIFIER_ZP_HEIGHT;
     (value->zp).width	= DEFAULT_MAGNIFIER_ZP_WIDTH;
-    
     value->zoomfactorx	= DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
     value->zoomfactory	= DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
     value->zoomfactor_lock	= DEFAULT_MAGNIFIER_ZOOM_FACTOR_LOCK;
@@ -169,7 +172,7 @@ magconf_setting_init (const gchar *id,
     value->cursor_state	= DEFAULT_MAGNIFIER_CURSOR;
     value->cursor_name	= g_strdup (DEFAULT_MAGNIFIER_CURSOR_NAME);
     value->cursor_size	= DEFAULT_MAGNIFIER_CURSOR_SIZE;
-    value->cursor_mag   = DEFAULT_MAGNIFIER_CURSOR_MAG;
+    value->cursor_scale = DEFAULT_MAGNIFIER_CURSOR_SCALE;
     value->cursor_color = DEFAULT_MAGNIFIER_CURSOR_COLOR;
     
     value->crosswire 	= DEFAULT_MAGNIFIER_CROSSWIRE;
@@ -180,6 +183,9 @@ magconf_setting_init (const gchar *id,
     value->mouse_tracking = g_strdup (DEFAULT_MAGNIFIER_MOUSE_TRACKING);
     value->tracking  	  = g_strdup (DEFAULT_MAGNIFIER_TRACKING);
     
+    value->alignment_x   = g_strdup (DEFAULT_MAGNIFIER_ALIGNMENT_X);
+    value->alignment_y   = g_strdup (DEFAULT_MAGNIFIER_ALIGNMENT_Y);
+        
     if (!set_struct)
 	return value;
     
@@ -231,6 +237,8 @@ magconf_setting_free (Magnifier* magnifier)
     g_free (magnifier->cursor_name);
     g_free (magnifier->smoothing);
     g_free (magnifier->mouse_tracking);
+    g_free (magnifier->alignment_x);
+    g_free (magnifier->alignment_y);
     g_free (magnifier->tracking);
     g_free (magnifier->source);
     g_free (magnifier->target);
@@ -265,7 +273,8 @@ magconf_load_zoomer_from_schema (const gchar *schema,
 {
     Magnifier *magnifier = NULL;
     gchar *path = NULL;
-
+    gint size_x, size_y;
+    
     sru_return_val_if_fail (schema, NULL);    
     sru_return_val_if_fail (zoomer, NULL);    
     
@@ -273,6 +282,8 @@ magconf_load_zoomer_from_schema (const gchar *schema,
     
     sru_assert (magnifier);
     
+    magconf_get_display_size (&size_x, &size_y);
+    
     path = g_strdup_printf ("%s/%s/%s", 
 			    CONFIG_PATH MAGNIFIER_PATH, 
 			    schema, 
@@ -295,7 +306,7 @@ magconf_load_zoomer_from_schema (const gchar *schema,
     (magnifier->zp).left 	= gnopiconf_get_int_from_section_with_default (
 								path, 	
 								MAGNIFIER_ZP_LEFT, 	
-								DEFAULT_MAGNIFIER_ZP_LEFT);
+								size_x / 2);
     (magnifier->zp).top 	= gnopiconf_get_int_from_section_with_default (
 								path, 	
 								MAGNIFIER_ZP_TOP, 	
@@ -303,11 +314,11 @@ magconf_load_zoomer_from_schema (const gchar *schema,
     (magnifier->zp).width 	= gnopiconf_get_int_from_section_with_default (
 								path, 	
 								MAGNIFIER_ZP_WIDTH, 	
-								DEFAULT_MAGNIFIER_ZP_WIDTH);
+								size_x);
     (magnifier->zp).height 	= gnopiconf_get_int_from_section_with_default (
 								path, 	
 								MAGNIFIER_ZP_HEIGHT, 	
-								DEFAULT_MAGNIFIER_ZP_HEIGHT);
+								size_y);
     magnifier->visible 		= gnopiconf_get_bool_from_section_with_default (
 								path,	
 								MAGNIFIER_VISIBLE, 	
@@ -321,11 +332,11 @@ magconf_load_zoomer_from_schema (const gchar *schema,
 								MAGNIFIER_PANNING, 	
 								DEFAULT_MAGNIFIER_PANNING);
 
-    magnifier->zoomfactorx	= gnopiconf_get_int_from_section_with_default (
+    magnifier->zoomfactorx	= gnopiconf_get_double_from_section_with_default (
 								path, 	
 								MAGNIFIER_ZOOM_FACTOR_X, 	
 								DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY);
-    magnifier->zoomfactory	= gnopiconf_get_int_from_section_with_default (
+    magnifier->zoomfactory	= gnopiconf_get_double_from_section_with_default (
 								path, 	
 								MAGNIFIER_ZOOM_FACTOR_Y, 	
 								DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY);
@@ -349,10 +360,11 @@ magconf_load_zoomer_from_schema (const gchar *schema,
 								path, 	
 								MAGNIFIER_CURSOR_SIZE, 	
 								DEFAULT_MAGNIFIER_CURSOR_SIZE);
-    magnifier->cursor_mag   	= gnopiconf_get_bool_from_section_with_default (
+
+    magnifier->cursor_scale   	= gnopiconf_get_bool_from_section_with_default (
 								path, 	
-								MAGNIFIER_CURSOR_MAG, 	
-								DEFAULT_MAGNIFIER_CURSOR_MAG);
+								MAGNIFIER_CURSOR_SCALE, 	
+								DEFAULT_MAGNIFIER_CURSOR_SCALE);
     magnifier->cursor_color   	= gnopiconf_get_int_from_section_with_default (
 								path, 	
 								MAGNIFIER_CURSOR_COLOR, 	
@@ -386,6 +398,15 @@ magconf_load_zoomer_from_schema (const gchar *schema,
 								path, 	
 								MAGNIFIER_MOUSE_TRACKING,	
 								DEFAULT_MAGNIFIER_MOUSE_TRACKING);    
+    magnifier->alignment_x 	= gnopiconf_get_string_from_section_with_default (
+								path,
+								MAGNIFIER_ALIGNMENT_X,
+								DEFAULT_MAGNIFIER_ALIGNMENT_X);
+    magnifier->alignment_y 	= gnopiconf_get_string_from_section_with_default (
+								path,
+								MAGNIFIER_ALIGNMENT_Y,
+								DEFAULT_MAGNIFIER_ALIGNMENT_Y);
+
     magnifier->tracking  	= gnopiconf_get_string_from_section_with_default (
 								path, 	
 								MAGNIFIER_TRACKING,	
@@ -414,6 +435,8 @@ magconf_set_setting_in_schema (	const gchar *id,
 			    CONFIG_PATH MAGNIFIER_PATH, 
 			    schema, 
 			    id);    
+    g_message ("setting gconf key %s", key);
+
     
     switch (data_type)
     {
@@ -427,6 +450,8 @@ magconf_set_setting_in_schema (	const gchar *id,
 	    gnopiconf_set_bool_in_section (*((gboolean*)data), path, key);
 	    break;
 	case GCONF_VALUE_FLOAT:
+	    gnopiconf_set_double_in_section (*((gdouble*)data), path, key);
+	    break;
 	case GCONF_VALUE_LIST:
 	default:
 	    break;
@@ -494,6 +519,11 @@ magconf_save_item_in_schema (const gchar *schema,
 						path, 	
 						key);
 	    break;
+	case GCONF_VALUE_FLOAT:
+		gnopiconf_set_double_in_section (*((gdouble*)data), 		
+						 path, 	
+						 key);
+	    break;
 	default:
 	 break;
     }
@@ -542,10 +572,10 @@ magconf_save_zoomer_in_schema (const gchar *schema,
 				    MAGNIFIER_PANNING);
 
 			
-    gnopiconf_set_int_in_section (magnifier->zoomfactorx, path, 	
-				    MAGNIFIER_ZOOM_FACTOR_X);
-    gnopiconf_set_int_in_section (magnifier->zoomfactory, path, 	
-				    MAGNIFIER_ZOOM_FACTOR_Y);
+    gnopiconf_set_double_in_section (magnifier->zoomfactorx, path, 	
+				     MAGNIFIER_ZOOM_FACTOR_X);
+    gnopiconf_set_double_in_section (magnifier->zoomfactory, path, 	
+				     MAGNIFIER_ZOOM_FACTOR_Y);
     gnopiconf_set_bool_in_section (magnifier->zoomfactor_lock, path, 
 				    MAGNIFIER_ZOOM_FACTOR_LOCK);
 
@@ -560,8 +590,9 @@ magconf_save_zoomer_in_schema (const gchar *schema,
 				    MAGNIFIER_CURSOR_NAME);
     gnopiconf_set_int_in_section (magnifier->cursor_size, path, 	
 				    MAGNIFIER_CURSOR_SIZE);
-    gnopiconf_set_bool_in_section (magnifier->cursor_mag, path, 	
-				    MAGNIFIER_CURSOR_MAG);
+    gnopiconf_set_bool_in_section (magnifier->cursor_scale, path, 	
+				    MAGNIFIER_CURSOR_SCALE);
+
     gnopiconf_set_int_in_section ((gint)magnifier->cursor_color, path, 	
 				    MAGNIFIER_CURSOR_COLOR);
 
@@ -578,6 +609,10 @@ magconf_save_zoomer_in_schema (const gchar *schema,
 			
     gnopiconf_set_string_in_section (magnifier->mouse_tracking, path, 
 					MAGNIFIER_MOUSE_TRACKING);
+    gnopiconf_set_string_in_section (magnifier->alignment_x, path, 
+					MAGNIFIER_ALIGNMENT_X);
+    gnopiconf_set_string_in_section (magnifier->alignment_y, path, 
+					MAGNIFIER_ALIGNMENT_Y);
     gnopiconf_set_string_in_section (magnifier->tracking, path, 
 					MAGNIFIER_TRACKING);
     
@@ -590,13 +625,16 @@ void
 magconf_get_display_size (gint *size_x,
 			  gint *size_y)
 {
-    *size_x = gnopiconf_get_int_from_section_with_default (CONFIG_PATH MAGNIFIER_CONFIG_PATH, 	
-							   MAGNIFIER_DISPLAY_SIZE_X, 	
-							   DEFAULT_MAGNIFIER_DISPLAY_SIZE_X);
-
-    *size_y = gnopiconf_get_int_from_section_with_default (CONFIG_PATH MAGNIFIER_CONFIG_PATH, 	
-							   MAGNIFIER_DISPLAY_SIZE_Y, 	
-							   DEFAULT_MAGNIFIER_DISPLAY_SIZE_Y);
+    *size_x = gnopiconf_get_int_with_default (CONFIG_PATH MAGNIFIER_PATH "/"
+							DEFAULT_MAGNIFIER_SCHEMA "/"
+							DEFAULT_MAGNIFIER_ID "/"
+							MAGNIFIER_DISPLAY_SIZE_X,
+							DEFAULT_MAGNIFIER_DISPLAY_SIZE_X);
+    *size_y = gnopiconf_get_int_with_default (CONFIG_PATH MAGNIFIER_PATH "/"
+							DEFAULT_MAGNIFIER_SCHEMA "/"
+							DEFAULT_MAGNIFIER_ID "/"
+							MAGNIFIER_DISPLAY_SIZE_Y,
+							DEFAULT_MAGNIFIER_DISPLAY_SIZE_Y);
 }
 
 void
@@ -637,20 +675,20 @@ magconf_changes_cb			(GConfClient	*client,
 	else
 	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_ZOOM_FACTOR_X) == 0)
 	{
-	    if (entry->value->type == GCONF_VALUE_INT)
+	    if (entry->value->type == GCONF_VALUE_FLOAT)
 	    {
 		magnifier_setting->zoomfactorx = 
-		    gconf_value_get_int (entry->value);
+		    gconf_value_get_float (entry->value);
 		magui_set_zoomfactor_x(magnifier_setting);
 	    }
 	}
 	else
 	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_ZOOM_FACTOR_Y) == 0)
 	{
-	    if (entry->value->type == GCONF_VALUE_INT)
+	    if (entry->value->type == GCONF_VALUE_FLOAT)
 	    {
 		magnifier_setting->zoomfactory = 
-		    gconf_value_get_int (entry->value);
+		    gconf_value_get_float (entry->value);
 		magui_set_zoomfactor_y(magnifier_setting);
 	    }
 	}
@@ -725,17 +763,17 @@ magconf_changes_cb			(GConfClient	*client,
 	    }
 	}
 	else    
-	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_CURSOR_MAG) == 0)
+	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_CURSOR_SCALE) == 0)
 	{
 	    if (entry->value->type == GCONF_VALUE_BOOL)
 	    {
-	        magnifier_setting->cursor_mag = 
+	        magnifier_setting->cursor_scale = 
 		    gconf_value_get_bool (entry->value);
 		magui_set_cursor_mag (magnifier_setting);
 	    }
 	}
 	else
-	if (strcmp (key,CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_CURSOR_COLOR) == 0)
+	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_CURSOR_COLOR) == 0)
 	{
 	    if (entry->value->type == GCONF_VALUE_INT)
 	    {
@@ -826,5 +864,31 @@ magconf_changes_cb			(GConfClient	*client,
 		magui_set_mouse_tracking (magnifier_setting);
 	    }
 	}
-
+	else
+	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_DISPLAY_SIZE_X) == 0)
+	{
+	    if (entry->value->type == GCONF_VALUE_INT)
+	    {
+		magui_update_screen_boundary ();
+	    }
+	}
+	else
+	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_DISPLAY_SIZE_Y) == 0)
+	{
+	    if (entry->value->type == GCONF_VALUE_INT)
+	    {
+	    	magui_update_screen_boundary ();
+	    }
+	}
+/*	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_FOCUS_TRACKING) == 0)
+	{
+	    if (entry->value->type == GCONF_VALUE_STRING)
+	    {
+		g_free (magnifier_setting->focus_tracking);
+		magnifier_setting->focus_tracking = 
+		    g_strdup (gconf_value_get_string (entry->value));
+		magui_set_focus_tracking (magnifier_setting);
+	    }
+	}
+*/
 }
