@@ -987,7 +987,7 @@ static gboolean src_flat_review_next_line ();
 static gboolean src_flat_review_prev_line ();
 
 static gint crt_line = 0;
-static gboolean visited = FALSE;
+static gint last_line = -1;
 
 static gboolean
 src_nav_parent_flat ()
@@ -2621,7 +2621,7 @@ src_flat_review_line (gint index)
 
     sru_assert (1 <= index && index <= n_lines);
     
-    if (visited && (index == 1 || index == n_lines))
+    if ((index == 1 || index == n_lines) && last_line == index)
     {
 	if (index == 1 && src_use_speech)
 	{
@@ -2713,10 +2713,7 @@ src_flat_review_line (gint index)
     else if (line && (src_use_braille || src_use_braille_monitor))
 	src_present_line_to_braille_or_brlmon (line);
 	
-    if (index == 1 || index == n_lines)
-	visited = TRUE;
-    else
-	visited = FALSE;		
+    last_line = index;
 
     return TRUE;
 }
